aboutsummaryrefslogtreecommitdiff
path: root/engines/agos/rooms.cpp
diff options
context:
space:
mode:
authorEugene Sandulenko2006-09-29 09:44:30 +0000
committerEugene Sandulenko2006-09-29 09:44:30 +0000
commitbb1547ab1ce3eb0a586814949e59864888f99c83 (patch)
tree66e780855ef521dab3cfc5dcaad8e3d90f764f00 /engines/agos/rooms.cpp
parentabf4ede05ba070478cf942817140a6744015dfab (diff)
downloadscummvm-rg350-bb1547ab1ce3eb0a586814949e59864888f99c83.tar.gz
scummvm-rg350-bb1547ab1ce3eb0a586814949e59864888f99c83.tar.bz2
scummvm-rg350-bb1547ab1ce3eb0a586814949e59864888f99c83.zip
Phase 5 of Simon engine renaming. Renamed namespace Simon -> AGOS and
SimonEngine -> AGOSEngine. Source is compilable and runnable again. I'm done. svn-id: r24013
Diffstat (limited to 'engines/agos/rooms.cpp')
-rw-r--r--engines/agos/rooms.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/engines/agos/rooms.cpp b/engines/agos/rooms.cpp
index ca2b84e9f9..2af76d8c60 100644
--- a/engines/agos/rooms.cpp
+++ b/engines/agos/rooms.cpp
@@ -28,9 +28,9 @@
using Common::File;
-namespace Simon {
+namespace AGOS {
-uint16 SimonEngine::getDoorState(Item *item, uint16 d) {
+uint16 AGOSEngine::getDoorState(Item *item, uint16 d) {
uint16 mask = 3;
uint16 n;
@@ -46,7 +46,7 @@ uint16 SimonEngine::getDoorState(Item *item, uint16 d) {
return n;
}
-uint16 SimonEngine::getExitOf(Item *item, uint16 d) {
+uint16 AGOSEngine::getExitOf(Item *item, uint16 d) {
uint16 x;
uint16 y = 0;
@@ -62,7 +62,7 @@ uint16 SimonEngine::getExitOf(Item *item, uint16 d) {
return subRoom->roomExit[d];
}
-bool SimonEngine::loadRoomItems(uint item) {
+bool AGOSEngine::loadRoomItems(uint item) {
byte *p;
uint i, min_num, max_num;
char filename[30];
@@ -111,4 +111,4 @@ bool SimonEngine::loadRoomItems(uint item) {
return 0;
}
-} // End of namespace Simon
+} // End of namespace AGOS